@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 2014, Inverse inc.
+Copyright (c) 2014-2015, Inverse inc.
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
@@ -31,7 +31,6 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define __NSSTRINGACTIVESYNC_H__
 
 #import <Foundation/NSString.h>
-
 #include "SOGoActiveSyncConstants.h"
 
 @class NSCalendarDate;
@@ -51,7 +50,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 - (NSString *) command;
 - (NSString *) collectionid;
 - (NSString *) itemid;
+- (BOOL) acceptsMultiPart;
 - (NSData *) convertHexStringToBytes;
+- (NSString *) protocolVersion;
 
 @end
 
