@@ -1,6 +1,6 @@
 /* SOGo+DAV.m - this file is part of SOGo
  *
- * Copyright (C) 2010-2013 Inverse inc.
+ * Copyright (C) 2010-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,18 +18,12 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#import <Foundation/NSDictionary.h>
-#import <Foundation/NSEnumerator.h>
 
 #import <NGObjWeb/NSException+HTTP.h>
 #import <NGObjWeb/SoObject+SoDAV.h>
 #import <NGObjWeb/WOContext+SoObjects.h>
-#import <NGObjWeb/WORequest.h>
 #import <NGExtensions/NSObject+Logs.h>
 
-#import <DOM/DOMDocument.h>
-#import <DOM/DOMNode.h>
-#import <DOM/DOMProtocols.h>
 #import <SaxObjC/XMLNamespaces.h>
 
 #import <SOGo/NSArray+Utilities.h>
@@ -42,6 +36,7 @@
 #import <SOGo/SOGoPermissions.h>
 #import <SOGo/SOGoUser.h>
 #import <SOGo/SOGoUserFolder.h>
+#import <SOGo/SOGoUserManager.h>
 
 #import "SOGo+DAV.h"
 
@@ -184,9 +179,8 @@
     [hrefs addObject: [self davURLAsString]];
 }
 
-- (NSDictionary *)
-   _handlePrincipalMatchPrincipalProperty: (id <DOMElement>) child
-                                inContext: (WOContext *) localContext
+- (NSDictionary *)  _handlePrincipalMatchPrincipalProperty: (id <DOMElement>) child
+						 inContext: (WOContext *) localContext
 {
   NSMutableArray *hrefs;
   NSDictionary *response;
@@ -267,7 +261,7 @@
   NSObject <DOMNodeList> *list;
   NSObject <DOMNode> *valueNode;
   NSArray *elements;
-  NSString *property, *match;
+  NSString *property=nil, *match=nil;
 
   list = [searchElement getElementsByTagName: @"prop"];
   if ([list length])
@@ -365,31 +359,26 @@
     withEmailAddressSetMatching: (NSString *) value
                       inContext: (WOContext *) localContext
 {
-  id <SOGoSource> authenticationSource;
-  SOGoUser *activeUser;
+  SOGoUserManager *um;
   NSArray *records;
   NSUInteger count, max;
   NSString *uid;
   SOGoUserFolder *collection;
 
-  activeUser = [localContext activeUser];
-  if ([activeUser respondsToSelector: @selector (authenticationSource)])
+  um = [SOGoUserManager sharedUserManager];
+  records = [um fetchUsersMatching: value
+			  inDomain: [[localContext activeUser] domain]];
+
+  max = [records count];
+  for (count = 0; count < max; count++)
     {
-      authenticationSource = [[localContext activeUser] authenticationSource];
-      records = [authenticationSource
-                  fetchContactsMatching: value
-                               inDomain: [activeUser domain]];
-      max = [records count];
-      for (count = 0; count < max; count++)
-        {
-          uid = [[records objectAtIndex: count] objectForKey: @"c_uid"];
-          if ([uid length] > 0)
-            {
-              collection = [[SOGoUser userWithLogin: uid]
+      uid = [[records objectAtIndex: count] objectForKey: @"c_uid"];
+      if ([uid length] > 0)
+	{
+	  collection = [[SOGoUser userWithLogin: uid]
                              homeFolderInContext: localContext];
-              [collections addObject: collection];
-            }
-        }
+	  [collections addObject: collection];
+	}
     }
 }
 
@@ -585,7 +574,6 @@
                              @"addressbook", @"calendar-access",
                              @"calendar-schedule", @"calendar-auto-schedule",
                              @"calendar-proxy",
-
                              @"calendar-query-extended",
                              @"extended-mkcol",
                              @"calendarserver-principal-property-search",
