@@ -1,6 +1,6 @@
 /*
   Copyright (C) 2004-2005 SKYRIX Software AG
-  Copyright (C) 2006-2010 Inverse inc.
+  Copyright (C) 2006-2016 Inverse inc.
 
   This file is part of SOPE.
 
@@ -184,12 +184,9 @@
 
 #import <Foundation/NSArray.h>
 #import <Foundation/NSDictionary.h>
-#import <Foundation/NSEnumerator.h>
-#import <Foundation/NSException.h>
 #import <NGExtensions/NSString+Ext.h>
 #import <NGExtensions/NSObject+Logs.h>
 
-#import <ctype.h>
 
 #import "NSCalendarDate+ICal.h"
 #import "NSCalendarDate+NGCards.h"
@@ -197,7 +194,6 @@
 
 #import "CardGroup.h"
 #import "iCalByDayMask.h"
-#import "iCalRecurrenceRule.h"
 
 NSString *iCalWeekDayString[] = { @"SU", @"MO", @"TU", @"WE", @"TH", @"FR",
 				  @"SA" };
@@ -291,6 +287,8 @@ NSString *iCalWeekDayString[] = { @"SU", @"MO", @"TU", @"WE", @"TH", @"FR",
   NSString *frequency;
   iCalRecurrenceFrequency freq;
 
+  freq = 0;
+
   if ([value length] > 0)
     {
       frequency = [value uppercaseString];
@@ -308,11 +306,7 @@ NSString *iCalWeekDayString[] = { @"SU", @"MO", @"TU", @"WE", @"TH", @"FR",
 	freq = iCalRecurrenceFrequenceMinutely;
       else if ([frequency isEqualToString:@"SECONDLY"])
 	freq = iCalRecurrenceFrequenceSecondly;
-      else
-	freq = NSNotFound;
     }
-  else
-    freq = NSNotFound;
 
   return freq;
 }
@@ -409,6 +403,11 @@ NSString *iCalWeekDayString[] = { @"SU", @"MO", @"TU", @"WE", @"TH", @"FR",
   return [[self flattenedValuesForKey: @"count"] intValue];
 }
 
+- (BOOL) hasRepeatCount
+{
+  return [[self flattenedValuesForKey: @"count"] length] > 0;
+}
+
 - (void) setCount: (NSString *) _count
 {
   [self setSingleValue: _count forKey: @"count"];
@@ -467,9 +466,16 @@ NSString *iCalWeekDayString[] = { @"SU", @"MO", @"TU", @"WE", @"TH", @"FR",
 
 - (iCalByDayMask *) byDayMask
 {
+  NSArray *setPos;
+  NSString *day;
+
   if (dayMask == nil && [[self byDay] length])
     {
-      dayMask = [iCalByDayMask byDayMaskWithRuleString: [self byDay]];
+      day = [self byDay];
+      setPos = [self bySetPos];
+      if ([setPos count])
+        day = [NSString stringWithFormat: @"%@%@", [setPos lastObject], day];
+      dayMask = [iCalByDayMask byDayMaskWithRuleString: day];
       [dayMask retain];
     }
   
@@ -915,4 +921,28 @@ NSString *iCalWeekDayString[] = { @"SU", @"MO", @"TU", @"WE", @"TH", @"FR",
   return isEqual;
 }
 
+- (NSString *) description
+{
+  NSMutableString *str;
+
+  str = [NSMutableString stringWithString: [self flattenedValuesForKey: @"freq"]];
+
+  if ([self repeatInterval] > 1)
+    [str appendFormat: @" interval of %i", [self repeatInterval]];
+  if ([self repeatCount])
+    [str appendFormat: @" for %i times", [self repeatCount]];
+  if ([self untilDate])
+    [str appendFormat: @" until %@", [self untilDate]];
+  if ([[self valuesAtIndex: 0 forKey: @"bymonthday"] count])
+    [str appendFormat: @" BYMONTHDAY:%@", [self flattenedValuesForKey: @"bymonthday"]];
+  if ([[self valuesAtIndex: 0 forKey: @"byday"] count])
+    [str appendFormat: @" BYDAY:%@", [self flattenedValuesForKey: @"byday"]];
+  if ([[self valuesAtIndex: 0 forKey: @"bymonth"] count])
+    [str appendFormat: @" BYMONTH:%@", [self flattenedValuesForKey: @"bymonth"]];
+  if ([[self valuesAtIndex: 0 forKey: @"bysetpos"] count])
+    [str appendFormat: @" BYSETPOS:%@", [self flattenedValuesForKey: @"bysetpos"]];
+
+  return str;
+}
+
 @end /* iCalRecurrenceRule */
