@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2006-2020 Inverse inc.
+  Copyright (C) 2006-2021 Inverse inc.
   Copyright (C) 2000-2005 SKYRIX Software AG
 
   This file is part of SOGo.
@@ -106,7 +106,9 @@
   if (!oldStartDate)
     {
       ASSIGN (oldStartDate, [[self previousApt] startDate]);
-      [oldStartDate setTimeZone: viewTZ];
+      if ([[self previousApt] isKindOfClass: [iCalToDo class]] ||
+          ![(iCalEvent*)[self previousApt] isAllDay])
+        [oldStartDate setTimeZone: viewTZ];
     }
   return oldStartDate;
 }
@@ -116,33 +118,57 @@
   if (!newStartDate)
     {
       ASSIGN (newStartDate, [[self apt] startDate]);
-      [newStartDate setTimeZone: viewTZ];
+      if ([[self apt] isKindOfClass: [iCalToDo class]] ||
+          ![(iCalEvent*)[self apt] isAllDay])
+        [newStartDate setTimeZone: viewTZ];
     }
   return newStartDate;
 }
 
 - (NSCalendarDate *) oldEndDate
 {
+  NSCalendarDate *endDate;
+
   if (!oldEndDate)
     {
       if ([[self previousApt] isKindOfClass: [iCalEvent class]])
-        ASSIGN (oldEndDate, [(iCalEvent*)[self previousApt] endDate]);
+        {
+          endDate = [(iCalEvent*)[self previousApt] endDate];
+          if ([(iCalEvent*)[self previousApt] isAllDay])
+            endDate = [endDate dateByAddingYears:0 months:0 days:0 hours:0 minutes:0 seconds:-1];
+          else
+            [endDate setTimeZone: viewTZ];
+          ASSIGN (oldEndDate, endDate);
+        }
       else
-        ASSIGN (oldEndDate, [(iCalToDo*)[self previousApt] due]);
-      [oldEndDate setTimeZone: viewTZ];
+        {
+          ASSIGN (oldEndDate, [(iCalToDo*)[self previousApt] due]);
+          [oldEndDate setTimeZone: viewTZ];
+        }
     }
   return oldEndDate;
 }
 
 - (NSCalendarDate *) newEndDate
 {
+  NSCalendarDate *endDate;
+
   if (!newEndDate)
     {
       if ([[self apt] isKindOfClass: [iCalEvent class]])
-        ASSIGN (newEndDate, [(iCalEvent*)[self apt] endDate]);
+        {
+          endDate = [(iCalEvent*)[self apt] endDate];
+          if ([(iCalEvent*)[self apt] isAllDay])
+            endDate = [endDate dateByAddingYears:0 months:0 days:0 hours:0 minutes:0 seconds:-1];
+          else
+            [endDate setTimeZone: viewTZ];
+          ASSIGN (newEndDate, endDate);
+        }
       else
-        ASSIGN (newEndDate, [(iCalToDo*)[self apt] due]);
-      [newEndDate setTimeZone: viewTZ];
+        {
+          ASSIGN (newEndDate, [(iCalToDo*)[self apt] due]);
+          [newEndDate setTimeZone: viewTZ];
+        }
     }
   return newEndDate;
 }
