@@ -1,8 +1,6 @@
 /* NSDictionary+LDIF.m - this file is part of SOGo
  *
- * Copyright (C) 2011-2012 Inverse inc
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2011-2016 Inverse inc
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +19,6 @@
  */
 
 #import <Foundation/NSArray.h>
-#import <Foundation/NSString.h>
 #import <NGExtensions/NGBase64Coding.h>
 
 #import "NSString+LDIF.h"
