@@ -1,6 +1,6 @@
 /* SOGoContactSourceFolder.h - this file is part of SOGo
  *
- * Copyright (C) 2006-2013 Inverse inc.
+ * Copyright (C) 2006-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #ifndef SOGOCONTACTSOURCEFOLDER_H
 #define SOGOCONTACTSOURCEFOLDER_H
 
-#import "SOGoContactFolder.h"
 #import "SOGoFolder+CardDAV.h"
 
 #import <SOGo/SOGoSource.h>
@@ -50,6 +49,8 @@
 - (void) setIsPersonalSource: (BOOL) isPersonal;
 - (BOOL) isPersonalSource;
 
+- (BOOL) listRequiresDot;
+
 @end
 
 
