@@ -56,6 +56,7 @@
   int sourceIMAP4ID;
   NSMutableDictionary *headers;
   NSString *inReplyTo;
+  NSString *references;
   NSString *text;
   NSString *sourceURL;
   NSString *sourceFlag;
@@ -63,6 +64,7 @@
   BOOL isHTML;
   BOOL sign;
   BOOL encrypt;
+  NSMutableArray *tmpFiles;
 
   // Used during S/MIME encryption
   NSMutableDictionary *certificates;
@@ -95,6 +97,9 @@
 - (NSString *) inReplyTo;
 - (void) setInReplyTo: (NSString *) newInReplyTo;
 
+- (NSString *) references;
+- (void) setReferences: (NSString *) newReferences;
+
 - (void) setSourceURL: (NSString *) newSurceURL;
 - (void) setSourceFlag: (NSString *) newSourceFlag;
 - (void) setSourceFolder: (NSString *) newSourceFolder;
@@ -117,7 +122,7 @@
 
 /* NGMime representations */
 
-- (NSData *) mimeMessageForRecipient: (NSString *) theRecipient;
+- (NSData *)mimeMessageForRecipient:(NSString *)theRecipient extractingImages:(BOOL)extractImage;
 
 /* operations */
 - (NSArray *) allRecipients;
