@@ -20,15 +20,13 @@
   02111-1307, USA.
 */
 
-#import <Foundation/NSDictionary.h>
-#import <Foundation/NSString.h>
 
 #import <NGObjWeb/NSException+HTTP.h>
 #import <NGObjWeb/WOContext+SoObjects.h>
+#import <NGObjWeb/WORequest.h>
 #import <NGExtensions/NSNull+misc.h>
 #import <NGExtensions/NSObject+Logs.h>
 #import <DOM/DOMElement.h>
-#import <DOM/DOMProtocols.h>
 
 #import "../SOGo/NSArray+Utilities.h"
 #import "../SOGo/NSObject+DAV.h"
@@ -78,20 +76,23 @@
 {
   id obj;
   NSArray *accounts;
+  NSString *key;
   SOGoUser *user;
   int keyCount;
+
+  key = [_key fromCSSIdentifier];
   
   /* first check attributes directly bound to the application */
-  obj = [super lookupName:_key inContext:_ctx acquire:NO];
+  obj = [super lookupName:key inContext:_ctx acquire:NO];
   if (!obj)
     {
       user = [SOGoUser userWithLogin: [self ownerInContext: nil]];
       accounts = [user mailAccounts];
 
-      keyCount = [_key intValue];
-      if ([_key isEqualToString: [NSString stringWithFormat: @"%d", keyCount]]
+      keyCount = [key intValue];
+      if ([key isEqualToString: [NSString stringWithFormat: @"%d", keyCount]]
           && keyCount > -1 && keyCount < [accounts count])
-        obj = [SOGoMailAccount objectWithName: _key inContainer: self];
+        obj = [SOGoMailAccount objectWithName: key inContainer: self];
       else
         obj = [NSException exceptionWithHTTPStatus: 404 /* Not Found */];
     }
@@ -233,7 +234,7 @@
           labelNode = [labelNodes objectAtIndex: count];
           
           label = [labelNode attribute: @"id"];
-          name = [labelNode textValue];
+          name = [[labelNode firstChild] nodeValue];
           color = [labelNode attribute: @"color"];
 
           [values addObject: name];
