@@ -112,6 +112,9 @@
 @interface SOGoMailKazakhForward : SOGoMailForward
 @end
 
+@interface SOGoMailKoreanForward : SOGoMailForward
+@end
+
 @interface SOGoMailLatvianForward : SOGoMailForward
 @end
 
@@ -163,6 +166,9 @@
 @interface SOGoMailSwedishForward : SOGoMailForward
 @end
 
+@interface SOGoMailThaiForward : SOGoMailForward
+@end
+
 @interface SOGoMailTurkishTurkeyForward : SOGoMailForward
 @end
 
