@@ -366,6 +366,9 @@
 @implementation SOGoMailKazakhForward
 @end
 
+@implementation SOGoMailKoreanForward
+@end
+
 @implementation SOGoMailLatvianForward
 @end
 
@@ -417,6 +420,9 @@
 @implementation SOGoMailSwedishForward
 @end
 
+@implementation SOGoMailThaiForward
+@end
+
 @implementation SOGoMailTurkishTurkeyForward
 @end
 
