@@ -108,6 +108,9 @@
 @interface SOGoMailJapaneseReply : SOGoMailReply
 @end
 
+@interface SOGoMailKoreanReply : SOGoMailReply
+@end
+
 @interface SOGoMailKazakhReply : SOGoMailReply
 @end
 
@@ -162,6 +165,9 @@
 @interface SOGoMailSwedishReply : SOGoMailReply
 @end
 
+@interface SOGoMailThaiReply : SOGoMailReply
+@end
+
 @interface SOGoMailTurkishTurkeyReply : SOGoMailReply
 @end
 
