@@ -167,6 +167,9 @@
 @implementation SOGoMailKazakhReply
 @end
 
+@implementation SOGoMailKoreanReply
+@end
+
 @implementation SOGoMailLatvianReply
 @end
 
@@ -218,6 +221,9 @@
 @implementation SOGoMailSwedishReply
 @end
 
+@implementation SOGoMailThaiReply
+@end
+
 @implementation SOGoMailTurkishTurkeyReply
 @end
 
