@@ -1,6 +1,6 @@
 /* LDAPSource.m - this file is part of SOGo
  *
- * Copyright (C) 2007-2019 Inverse inc.
+ * Copyright (C) 2007-2022 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -106,6 +106,9 @@ static Class NSStringK;
       _filter = nil;
       _userPasswordAlgorithm = nil;
       _listRequiresDot = YES;
+      _globalAddressBookFirstEntriesCount = -1;
+
+      _disableSubgroups = NO;
 
       _passwordPolicy = NO;
       _updateSambaNTLMPasswords = NO;
@@ -170,7 +173,7 @@ static Class NSStringK;
                inDomain: (NSString *) sourceDomain
 {
   SOGoDomainDefaults *dd;
-  NSNumber *udQueryLimit, *udQueryTimeout, *udGroupExpansionEnabled, *dotValue;
+  NSNumber *udQueryLimit, *udQueryTimeout, *udGroupExpansionEnabled, *dotValue, *disableSubgroupsValue;
 
   if ((self = [self init]))
     {
@@ -200,10 +203,19 @@ static Class NSStringK;
             andMultipleBookingsField: [udSource objectForKey: @"MultipleBookingsFieldName"]];
 
       dotValue = [udSource objectForKey: @"listRequiresDot"];
-      if (dotValue)
+      if (dotValue) {
         [self setListRequiresDot: [dotValue boolValue]];
+        if ([udSource objectForKey: @"globalAddressBookFirstEntriesCount"])
+          [self setGlobalAddressBookFirstEntriesCount: [[udSource objectForKey: @"globalAddressBookFirstEntriesCount"] intValue]];
+      }
+
+      disableSubgroupsValue = [udSource objectForKey: @"disableSubgroups"];
+      if (disableSubgroupsValue)
+        _disableSubgroups = [disableSubgroupsValue boolValue];
+
       [self setContactMapping: [udSource objectForKey: @"mapping"]
              andObjectClasses: [udSource objectForKey: @"objectClasses"]];
+             
 
       [self setModifiers: [udSource objectForKey: @"modifiers"]];
       ASSIGN(_abOU, [udSource objectForKey: @"abOU"]);
@@ -400,11 +412,26 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return _listRequiresDot;
 }
 
+- (void) setGlobalAddressBookFirstEntriesCount: (int)value
+{
+  _globalAddressBookFirstEntriesCount = value;
+}
+
+- (int) globalAddressBookFirstEntriesCount
+{
+  return _globalAddressBookFirstEntriesCount;
+}
+
 - (NSArray *) searchFields
 {
   return _searchFields;
 }
 
+- (NSArray *) userPasswordPolicy
+{
+  return nil;
+}
+
 - (void) setContactMapping: (NSDictionary *) theMapping
           andObjectClasses: (NSArray *) theObjectClasses
 {
@@ -437,7 +464,7 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
 //
 //
 //
-- (NGLdapConnection *) _ldapConnection
+- (id) connection
 {
   NGLdapConnection *ldapConnection;
   NSString *value, *key;
@@ -492,6 +519,22 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return ldapConnection;
 }
 
+- (NGLdapConnection *) _ldapConnection
+{
+  return (NGLdapConnection *)[self connection];
+}
+
+- (BOOL) isConnected
+{
+  return [[self _ldapConnection] isBound];
+}
+
+- (void) releaseConnection: (id) connection
+{
+  if ([(NGLdapConnection *)connection isBound])
+    [(NGLdapConnection *)connection unbind];
+}
+
 - (NSString *) domain
 {
   return _domain;
@@ -687,14 +730,53 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return didChange;
 }
 
-//
-//
-//
+- (BOOL)  _ldapAdminModifyAttribute: (NSString *) theAttribute
+                     withValue: (NSString *) theValue
+                        userDN: (NSString *) theUserDN
+                    connection: (NGLdapConnection *) bindConnection
+{
+  NGLdapModification *mod;
+  NGLdapAttribute *attr;
+  NSArray *changes;
+
+  BOOL didChange;
+
+  attr = [[NGLdapAttribute alloc] initWithAttributeName: theAttribute];
+  [attr addStringValue: theValue];
+
+  mod = [NGLdapModification replaceModification: attr];
+
+  changes = [NSArray arrayWithObject: mod];
+
+  if ([bindConnection bindWithMethod: @"simple"
+                              binddn: _bindDN
+                         credentials: _password])
+    {
+      didChange = [bindConnection modifyEntryWithDN: theUserDN
+                                            changes: changes];
+    }
+  else
+    didChange = NO;
+
+  RELEASE(attr);
+
+  return didChange;
+}
+
+/**
+ * Change a user's password.
+ * @param login the user's login name.
+ * @param oldPassword the previous password.
+ * @param newPassword the new password.
+ * @param perr will be set if the new password is not conform to the policy.
+ * @param passwordRecovery YES of this is password recovery, NO otherwise. If password recovery is set, old password won't be checked
+ * @return YES if the password was successfully changed.
+ */
 - (BOOL) changePasswordForLogin: (NSString *) login
                     oldPassword: (NSString *) oldPassword
                     newPassword: (NSString *) newPassword
+               passwordRecovery: (BOOL) passwordRecovery
                            perr: (SOGoPasswordPolicyError *) perr
-
 {
   NGLdapConnection *bindConnection;
   NSString *userDN;
@@ -702,6 +784,8 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
 
   didChange = NO;
 
+  [self updateBaseDNFromLogin: login];
+
   NS_DURING
     if ([login length] > 0)
       {
@@ -760,20 +844,38 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
 
                     if (encryptedPass != nil)
                       {
-                        if ([bindConnection bindWithMethod: @"simple"
+                        if (!passwordRecovery) {
+                          if ([bindConnection bindWithMethod: @"simple"
                                                     binddn: userDN
                                                credentials: oldPassword])
-                          {
-                            didChange = [self _ldapModifyAttribute: @"userPassword"
-                                                         withValue: encryptedPass
-                                                            userDN: userDN
-                                                          password: oldPassword
-                                                        connection: bindConnection];
-                            if (didChange)
                               {
-                                *perr = PolicyNoError;
+                                didChange = [self _ldapModifyAttribute: @"userPassword"
+                                                            withValue: encryptedPass
+                                                                userDN: userDN
+                                                              password: oldPassword
+                                                            connection: bindConnection];
+                                if (didChange)
+                                  {
+                                    *perr = PolicyNoError;
+                                  }
                               }
-                          }
+                        } else {
+                          // Password recovery
+                          // As old password is unknown, we use admin binding
+                          if ([bindConnection bindWithMethod: @"simple"
+                                                      binddn: _bindDN
+                                                 credentials: _password])
+                              {
+                                didChange = [self _ldapAdminModifyAttribute: @"userPassword"
+                                                                  withValue: encryptedPass
+                                                                     userDN: userDN
+                                                                 connection: bindConnection];
+                                if (didChange)
+                                  {
+                                    *perr = PolicyNoError;
+                                  }
+                              }
+                        }
                       }
                   }
 
@@ -908,6 +1010,30 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return [EOQualifier qualifierWithQualifierFormat: qs];
 }
 
+- (void) addVCardProperty: (NSString *) property
+               toCriteria: (NSMutableArray *) criteria
+{
+  static NSDictionary *vCardLDAPFieldsTable = nil;
+  NSString *field;
+
+  if (!vCardLDAPFieldsTable)
+    vCardLDAPFieldsTable = [[NSDictionary alloc] initWithObjectsAndKeys:
+                                                   @"cn",            @"fn",
+                                                 @"cn",              @"n",
+                                                 @"mail",            @"email",
+                                                 @"mail",            @"mail",
+                                                 @"telephonenumber", @"tel",
+                                                 @"o",               @"org",
+                                                 @"l",               @"adr",
+                                                  nil];
+
+  field = [vCardLDAPFieldsTable objectForKey: property];
+  if (field)
+    {
+      [criteria addObjectUniquely: field];
+    }
+}
+
 /*
 - (NSArray *) _constraintsFields
 {
@@ -1283,45 +1409,117 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
                        withCriteria: (NSArray *) criteria
                            inDomain: (NSString *) theDomain
 {
+  if ([match length] > 0) {
+    return [self fetchContactsMatching: (NSString *) match
+                       withCriteria: (NSArray *) criteria
+                           inDomain: (NSString *) theDomain
+                              limit: -1];
+  } else {
+    return [NSMutableArray array];
+  }
+}
+
+- (NSArray *) fetchContactsMatching: (NSString *) match
+                       withCriteria: (NSArray *) criteria
+                           inDomain: (NSString *) theDomain
+                              limit: (int) limit
+{
+  NSAutoreleasePool *pool;
   NGLdapConnection *ldapConnection;
   NGLdapEntry *currentEntry;
   NSEnumerator *entries;
   NSMutableArray *contacts;
   EOQualifier *qualifier;
+  unsigned int i;
+  NSMutableString *s;
+  NSString *sortAttribute;
+  BOOL sortReverse;
 
   contacts = [NSMutableArray array];
 
+  if(theDomain != nil && [theDomain length] > 0)
+  {
+    if ([_pristineBaseDN rangeOfString: @"%d"].location != NSNotFound)
+    {
+      s = [NSMutableString stringWithString: _pristineBaseDN];
+      [s replaceOccurrencesOfString: @"%d"  withString: theDomain  options: 0  range: NSMakeRange(0, [s length])];
+      ASSIGN(_baseDN, s);
+    }
+  }
+
   if ([match length] > 0 || !_listRequiresDot)
     {
       ldapConnection = [self _ldapConnection];
       qualifier = [self _qualifierForFilter: match onCriteria: criteria];
 
-      if ([_scope caseInsensitiveCompare: @"BASE"] == NSOrderedSame)
-        entries = [ldapConnection baseSearchAtBaseDN: _baseDN
-                                           qualifier: qualifier
-                                          attributes: _lookupFields];
-      else if ([_scope caseInsensitiveCompare: @"ONE"] == NSOrderedSame)
-        entries = [ldapConnection flatSearchAtBaseDN: _baseDN
-                                           qualifier: qualifier
-                                          attributes: _lookupFields];
-      else /* we do it like before */
-        entries = [ldapConnection deepSearchAtBaseDN: _baseDN
-                                           qualifier: qualifier
-                                          attributes: _lookupFields];
+      if (limit > 0) {
+        [ldapConnection setQuerySizeLimit: limit];
+      }
+
+      if (limit > 0) {
+        // Sort results
+        sortAttribute = @"cn";
+        sortReverse = NO;
+        if ([_scope caseInsensitiveCompare: @"BASE"] == NSOrderedSame)
+          entries = [ldapConnection baseSearchAtBaseDN: _baseDN
+                                             qualifier: qualifier
+                                            attributes: _lookupFields
+                                         sortAttribute: sortAttribute
+                                           sortReverse: sortReverse];
+        else if ([_scope caseInsensitiveCompare: @"ONE"] == NSOrderedSame)
+          entries = [ldapConnection flatSearchAtBaseDN: _baseDN
+                                             qualifier: qualifier
+                                            attributes: _lookupFields
+                                         sortAttribute: sortAttribute
+                                           sortReverse: sortReverse];
+        else /* we do it like before */
+          entries = [ldapConnection deepSearchAtBaseDN: _baseDN
+                                            qualifier: qualifier
+                                           attributes: _lookupFields
+                                        sortAttribute: sortAttribute
+                                          sortReverse: sortReverse];
+      } else {
+        // No sort results
+        if ([_scope caseInsensitiveCompare: @"BASE"] == NSOrderedSame)
+          entries = [ldapConnection baseSearchAtBaseDN: _baseDN
+                                            qualifier: qualifier
+                                            attributes: _lookupFields];
+        else if ([_scope caseInsensitiveCompare: @"ONE"] == NSOrderedSame)
+          entries = [ldapConnection flatSearchAtBaseDN: _baseDN
+                                            qualifier: qualifier
+                                            attributes: _lookupFields];
+        else /* we do it like before */
+          entries = [ldapConnection deepSearchAtBaseDN: _baseDN
+                                            qualifier: qualifier
+                                            attributes: _lookupFields];
+      }
+      
+
+      i = 0;
+      pool = [NSAutoreleasePool new];
       while ((currentEntry = [entries nextObject]))
-        [contacts addObject:
-                    [self _convertLDAPEntryToContact: currentEntry]];
+        {
+          [contacts addObject: [self _convertLDAPEntryToContact: currentEntry]];
+          i++;
+          if (i % 10 == 0)
+            {
+              [pool release];
+              pool = [NSAutoreleasePool new];
+            }
+        }
+      [pool release];
     }
 
   return contacts;
 }
 
 - (NGLdapEntry *) _lookupLDAPEntry: (EOQualifier *) theQualifier
+		   usingConnection: (id) connection
 {
   NGLdapConnection *ldapConnection;
   NSEnumerator *entries;
 
-  ldapConnection = [self _ldapConnection];
+  ldapConnection = (NGLdapConnection *)connection;
 
   if ([_scope caseInsensitiveCompare: @"BASE"] == NSOrderedSame)
     entries = [ldapConnection baseSearchAtBaseDN: _baseDN
@@ -1339,8 +1537,15 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return [entries nextObject];
 }
 
+- (NGLdapEntry *) _lookupLDAPEntry: (EOQualifier *) theQualifier
+{
+  return [self _lookupLDAPEntry: theQualifier
+		usingConnection: [self _ldapConnection]];
+}
+
 - (NSDictionary *) lookupContactEntry: (NSString *) theID
                              inDomain: (NSString *) theDomain
+		      usingConnection: (id) connection
 {
   NGLdapEntry *ldapEntry;
   EOQualifier *qualifier;
@@ -1354,7 +1559,8 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
       s = [NSString stringWithFormat: @"(%@='%@')",
                     _IDField, SafeLDAPCriteria(theID)];
       qualifier = [EOQualifier qualifierWithQualifierFormat: s];
-      ldapEntry = [self _lookupLDAPEntry: qualifier];
+      ldapEntry = [self _lookupLDAPEntry: qualifier
+			 usingConnection: connection];
       if (ldapEntry)
         ldifRecord = [self _convertLDAPEntryToContact: ldapEntry];
     }
@@ -1362,6 +1568,14 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
   return ldifRecord;
 }
 
+- (NSDictionary *) lookupContactEntry: (NSString *) theID
+                             inDomain: (NSString *) theDomain
+{
+  return [self lookupContactEntry: theID
+			 inDomain: theDomain
+		  usingConnection: [self _ldapConnection]];
+}
+
 - (NSDictionary *) lookupContactEntryWithUIDorEmail: (NSString *) uid
                                            inDomain: (NSString *) theDomain
 {
@@ -1482,6 +1696,55 @@ groupObjectClasses: (NSArray *) newGroupObjectClasses
 				    andValue: theEmail];
 }
 
+- (NSArray *) lookupContactsWithQualifier: (EOQualifier *) qualifier
+                          andSortOrdering: (EOSortOrdering *) ordering
+                                 inDomain: (NSString *) domain
+{
+  NSAutoreleasePool *pool;
+  NGLdapConnection *ldapConnection;
+  NGLdapEntry *currentEntry;
+  NSEnumerator *entries;
+  NSMutableArray *contacts;
+  unsigned int i;
+
+  contacts = [NSMutableArray array];
+
+  if ([qualifier count] > 0 || !_listRequiresDot)
+    {
+      ldapConnection = [self _ldapConnection];
+
+      // Perform the query if the qualifier is defined or if no critera was defined
+      if ([_scope caseInsensitiveCompare: @"BASE"] == NSOrderedSame)
+        entries = [ldapConnection baseSearchAtBaseDN: _baseDN
+                                           qualifier: qualifier
+                                          attributes: _lookupFields];
+      else if ([_scope caseInsensitiveCompare: @"ONE"] == NSOrderedSame)
+        entries = [ldapConnection flatSearchAtBaseDN: _baseDN
+                                           qualifier: qualifier
+                                          attributes: _lookupFields];
+      else /* we do it like before */
+        entries = [ldapConnection deepSearchAtBaseDN: _baseDN
+                                           qualifier: qualifier
+                                          attributes: _lookupFields];
+
+      i = 0;
+      pool = [NSAutoreleasePool new];
+      while ((currentEntry = [entries nextObject]))
+        {
+          [contacts addObject: [self _convertLDAPEntryToContact: currentEntry]];
+          i++;
+          if (i % 10 == 0)
+            {
+              [pool release];
+              pool = [NSAutoreleasePool new];
+            }
+        }
+      [pool release];
+    }
+
+  return contacts;
+}
+
 - (void) setSourceID: (NSString *) newSourceID
 {
   ASSIGN(_sourceID, newSourceID);
@@ -2040,8 +2303,7 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
   NSRange r;
 
   r = [theLogin rangeOfString: @"@"];
-  if (r.location != NSNotFound &&
-      [_pristineBaseDN rangeOfString: @"%d"].location != NSNotFound)
+  if (r.location != NSNotFound && [_pristineBaseDN rangeOfString: @"%d"].location != NSNotFound)
     {
       s = [NSMutableString stringWithString: _pristineBaseDN];
       [s replaceOccurrencesOfString: @"%d"  withString: [theLogin substringFromIndex: r.location+1]  options: 0  range: NSMakeRange(0, [s length])];
@@ -2056,7 +2318,7 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
 
 - (NSArray *) membersForGroupWithUID: (NSString *) uid
 {
-  NSMutableArray *dns, *uids;
+  NSMutableArray *dns, *uids, *userLogins;
   NSString *dn, *login;
   SOGoUserManager *um;
   NSDictionary *d, *contactInfos;
@@ -2077,6 +2339,7 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
       members = [NSMutableArray new];
       uids = [NSMutableArray array];
       dns = [NSMutableArray array];
+      userLogins = [NSMutableArray array];
 
       // We check if it's a static group
       // Fetch "members" - we get DNs
@@ -2108,19 +2371,31 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
               pool = [NSAutoreleasePool new];
               dn = [dns objectAtIndex: i];
               login = [um getLoginForDN: [dn lowercaseString]];
+              if([userLogins containsObject: login])
+              {
+                [pool release];
+                continue; //user alrady fetch
+              }
+              if(login != nil)
+                [userLogins addObject: login];
               user = [SOGoUser userWithLogin: login  roles: nil];
               if (user)
                 {
-                  contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
-                  if ([contactInfos objectForKey: @"isGroup"])
+                  if (!_disableSubgroups) {
+                    contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
+                    if ([contactInfos objectForKey: @"isGroup"])
                     {
                       subusers = [self membersForGroupWithUID: login];
                       [members addObjectsFromArray: subusers];
                     }
-                  else
+                    else
                     {
                       [members addObject: user];
                     }
+                  } else {
+                    [members addObject: user];
+                  }
+                  
                 }
               [pool release];
             }
@@ -2130,19 +2405,30 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
             {
               pool = [NSAutoreleasePool new];
               login = [uids objectAtIndex: i];
+              if([userLogins containsObject: login])
+              {
+                [pool release];
+                continue; //user alrady fetch
+              }
+              if(login != nil)
+                [userLogins addObject: login];
               user = [SOGoUser userWithLogin: login  roles: nil];
               if (user)
                 {
-                  contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
-                  if ([contactInfos objectForKey: @"isGroup"])
+                  if (!_disableSubgroups) {
+                    contactInfos = [self lookupContactEntryWithUIDorEmail: login inDomain: nil];
+                    if ([contactInfos objectForKey: @"isGroup"])
                     {
                       subusers = [self membersForGroupWithUID: login];
                       [members addObjectsFromArray: subusers];
                     }
-                  else
+                    else
                     {
                       [members addObject: user];
                     }
+                  } else {
+                    [members addObject: user];
+                  }
                 }
               [pool release];
             }
@@ -2197,4 +2483,4 @@ _makeLDAPChanges (NGLdapConnection *ldapConnection,
   return rc;
 }
 
-@end
+@end
\ No newline at end of file
