@@ -19,7 +19,6 @@
  */
 
 #import <Foundation/NSArray.h>
-#import <Foundation/NSEnumerator.h>
 #import <Foundation/NSString.h>
 
 #import "NSDictionary+DAV.h"
@@ -46,7 +45,7 @@
 {
   NSString *newTag;
 
-  newTag = [NSString stringWithFormat: @"n%d", [namespaces count]];
+  newTag = [NSString stringWithFormat: @"n%d", (int)[namespaces count]];
   [namespaces setObject: newTag forKey: newNS];
 
   return newTag;
