@@ -1,8 +1,6 @@
 /* NSString+DAV.h - this file is part of SOGo
  *
- * Copyright (C) 2008 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2008-2013 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,7 +21,6 @@
 #ifndef NSSTRING_DAV_H
 #define NSSTRING_DAV_H
 
-#import <Foundation/NSString.h>
 
 @class NSMutableDictionary;
 
