@@ -65,7 +65,8 @@
               domain: &domain
                 perr: &perr
               expire: &expire
-               grace: &grace]
+               grace: &grace
+      additionalInfo: nil]
         && perr == PolicyNoError);
         
   if (!rc)
@@ -85,6 +86,12 @@
   return rc;
 }
 
+- (NSArray *)getCookiesIfNeeded: (WOContext *)_ctx
+{
+  //Needs to be override by children if needed
+  return nil;
+}
+
 - (NSString *) passwordInContext: (WOContext *) context
 {
   NSString *auth, *password;
@@ -140,6 +147,7 @@
   return password;
 }
 
+
 /* create SOGoUser */
 
 - (SOGoUser *) userInContext: (WOContext *)_ctx
