@@ -78,7 +78,8 @@
 - (BOOL) appointmentSendEMailNotifications;
 - (BOOL) foldersSendEMailNotifications;
 - (NSArray *) calendarDefaultRoles;
-- (NSString *) calendarJistiBaseUrl;
+- (NSString *) calendarJitsiBaseUrl;
+- (NSString *) calendarJitsiRoomPrefix;
 - (NSArray *) contactsDefaultRoles;
 - (NSArray *) refreshViewIntervals;
 - (NSString *) subscriptionFolderFormat;
