@@ -169,7 +169,7 @@
   return [self stringArrayForKey: @"SOGoCalendarDefaultRoles"];
 }
 
-- (NSString *) calendarJistiBaseUrl
+- (NSString *) calendarJitsiBaseUrl
 {
   NSString *jitsiBaseUrl;
   jitsiBaseUrl = [self stringForKey: @"SOGoCalendarJitsiBaseUrl"];
@@ -179,6 +179,16 @@
   return jitsiBaseUrl;
 }
 
+- (NSString *) calendarJitsiRoomPrefix
+{
+  NSString *jitsiRoomPrefix;
+  jitsiRoomPrefix = [self stringForKey: @"SOGoCalendarJitsiRoomPrefix"];
+  if(!jitsiRoomPrefix)
+    jitsiRoomPrefix = @"SOGo_meeting/";
+
+  return jitsiRoomPrefix;
+}
+
 - (NSArray *) contactsDefaultRoles
 {
   return [self stringArrayForKey: @"SOGoContactsDefaultRoles"];
