@@ -48,6 +48,7 @@
 @class NSException;
 @class NSTimeZone;
 @class NSURL;
+@class NSUUID;
 
 @class WOContext;
 @class WORequest;
@@ -74,6 +75,9 @@
 + (NSString *) globallyUniqueObjectId;
 - (NSString *) globallyUniqueObjectId;
 
++ (NSString *) mailUniqueMessageId;
+- (NSString *) mailUniqueMessageId;
+
 + (id) objectWithName: (NSString *)_name inContainer:(id)_container;
 
 - (id) initWithName: (NSString *) _name inContainer:(id)_container;
@@ -103,7 +107,8 @@
 
 /* ownership */
 
-- (void) setOwner: (NSString *) newOwner;
+- (NSString *)owner;
+- (void)setOwner:(NSString *)newOwner;
 - (NSString *) ownerInContext: (id) _ctx;
 
 /* a helper that determines whether access rights can be ignored on
