@@ -21,7 +21,6 @@
 
 #import <unistd.h>
 
-
 #import <NGObjWeb/SoClass.h>
 #import <NGObjWeb/SoObject+SoDAV.h>
 #import <NGObjWeb/WOApplication.h>
@@ -111,11 +110,28 @@
 		   pid, (int) f, sequence++, (int) rndm];
 }
 
+
 - (NSString *) globallyUniqueObjectId
 {
   return [[self class] globallyUniqueObjectId];
 }
 
++ (NSString *) mailUniqueMessageId
+{
+  /*
+  843F8180-4E33-7B0B-6F1B-9847CAD3E6EB
+  */
+  return [[NSUUID UUID] UUIDString];
+}
+
+- (NSString *) mailUniqueMessageId
+{
+  /*
+  843F8180-4E33-7B0B-6F1B-9847CAD3E6EB
+  */
+  return [[self class] mailUniqueMessageId];
+}
+
 /* containment */
 
 + (id) objectWithName: (NSString *)_name inContainer:(id)_container
