@@ -54,7 +54,6 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
   return total;
 }
 
-
 @implementation SimpleOpenIdResponse
 
 - (id)init {
@@ -152,7 +151,7 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
 - (void) initializeWithConfig: (NSDictionary *) _config
 {
   SOGoSystemDefaults *sd;
-  id refreshTokenBool, domainInfo;
+  id refreshTokenBool, domainInfo, intForKey;
 
   if([_config objectForKey: @"SOGoOpenIdConfigUrl"] &&
       [_config objectForKey: @"SOGoOpenIdScope"] &&
@@ -164,7 +163,6 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
     openIdClient             = [_config objectForKey: @"SOGoOpenIdClient"];
     openIdClientSecret       = [_config objectForKey: @"SOGoOpenIdClientSecret"];
     openIdEmailParam         = [_config objectForKey: @"SOGoOpenIdEmailParam"];
-    openIdHttpVersion        = [_config objectForKey: @"SOGoOpenIdHttpVersion"];
 
     openIdEnableRefreshToken = NO;
     refreshTokenBool = [_config objectForKey: @"SOGoOpenIdEnableRefreshToken"];
@@ -176,8 +174,12 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
     if (domainInfo && [domainInfo respondsToSelector: @selector (boolValue)])
         sendDomainInfo = [domainInfo boolValue];
 
-      
-    userTokenInterval        = [_config objectForKey: @"SOGoOpenIdTokenCheckInterval"];
+    intForKey = [_config objectForKey: @"SOGoOpenIdTokenCheckInterval"];
+    if (intForKey && [intForKey respondsToSelector: @selector (intValue)])
+          userTokenInterval = [intForKey intValue];
+    else
+      userTokenInterval = 0;
+
     [self _loadSessionFromCache: forDomain];
 
     if(cacheUpdateNeeded)
@@ -223,7 +225,6 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
     openIdClient             = [sd openIdClient];
     openIdClientSecret       = [sd openIdClientSecret];
     openIdEmailParam         = [sd openIdEmailParam];
-    openIdHttpVersion        = [sd openIdHttpVersion];
     openIdEnableRefreshToken = [sd openIdEnableRefreshToken];
     userTokenInterval        = [sd openIdTokenCheckInterval];
     sendDomainInfo           = [sd openIdSendDomainInfo];
@@ -352,16 +353,19 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
         if(SOGoOpenIDDebugEnabled)
           NSLog(@"OpenId perform request: response is: %@", response);
 
+        curl_easy_cleanup(curl);
         return [response autorelease];
       }
       else if (status == 404)
       {
         [self errorWithFormat: @"OpenID endpoint not found (404): %@", endpoint];
+        curl_easy_cleanup(curl);
         return nil; 
       }
       else
       {
         [self errorWithFormat: @"OpenID server internal error during %@: %@", endpoint, response];
+        curl_easy_cleanup(curl);
         return nil;
       }
     }
@@ -370,7 +374,7 @@ size_t curl_body_function(void *ptr, size_t size, size_t nmemb, void *buffer)
       [self errorWithFormat: @"CURL error while accessing %@ (%d): %@", endpoint, rc,
             [NSString stringWithCString: strlen(error) ? error : curl_easy_strerror(rc)]];
     }
-    curl_easy_cleanup (curl);
+    curl_easy_cleanup(curl);
   }
   else
   {
