@@ -24,6 +24,8 @@
 
 #import "SOGoConstants.h"
 
+@class EOQualifier;
+@class EOSortOrdering;
 @class NSDictionary;
 @class NSException;
 @class NSString;
@@ -38,13 +40,17 @@
 
 - (NSString *) domain;
 - (NSArray *) searchFields;
+- (NSArray *) userPasswordPolicy;
 
 - (id) connection;
 - (void) releaseConnection: (id) connection;
+- (BOOL) isConnected;
 
 /* requires a "." to obtain the full list of contacts */
 - (void) setListRequiresDot: (BOOL) aBool;
 - (BOOL) listRequiresDot;
+- (void) setGlobalAddressBookFirstEntriesCount: (int)value;
+- (int) globalAddressBookFirstEntriesCount;
 
 - (BOOL) checkLogin: (NSString *) _login
 	   password: (NSString *) _pwd
@@ -53,9 +59,10 @@
 	      grace: (int *) _grace;
 
 - (BOOL) changePasswordForLogin: (NSString *) login
-		    oldPassword: (NSString *) oldPassword
-		    newPassword: (NSString *) newPassword
-			   perr: (SOGoPasswordPolicyError *) perr;
+                    oldPassword: (NSString *) oldPassword
+                    newPassword: (NSString *) newPassword
+               passwordRecovery: (BOOL) passwordRecovery
+                           perr: (SOGoPasswordPolicyError *) perr;
 
 - (NSDictionary *) lookupContactEntry: (NSString *) theID
                              inDomain: (NSString *) domain;
@@ -70,6 +77,14 @@
 - (NSArray *) fetchContactsMatching: (NSString *) filter
                        withCriteria: (NSArray *) criteria
                            inDomain: (NSString *) domain;
+- (NSArray *)fetchContactsMatching:(NSString *)filter
+                      withCriteria:(NSArray *)criteria
+                          inDomain:(NSString *)domain
+                             limit:(int)limit;
+
+- (NSArray *) lookupContactsWithQualifier: (EOQualifier *) qualifier
+                          andSortOrdering: (EOSortOrdering *) ordering
+                                 inDomain: (NSString *) domain;
 
 - (void) setSourceID: (NSString *) newSourceID;
 - (NSString *) sourceID;
@@ -88,6 +103,9 @@
 - (NSException *) updateContactEntry: (NSDictionary *) ldifRecord;
 - (NSException *) removeContactEntryWithID: (NSString *) aId;
 
+- (void) addVCardProperty: (NSString *) property
+               toCriteria: (NSMutableArray *) criteria;
+
 /* user address books */
 - (NSArray *) addressBookSourcesForUser: (NSString *) user;
 
