@@ -156,12 +156,14 @@ extern NSString *SOGoPasswordRecoverySecondaryEmail;
 - (void) setMailComposeFontSize: (int) newValue;
 - (int) mailComposeFontSize;
 
-- (void) setMailDisplayFullEmail: (BOOL *) newValue;
-- (BOOL *) mailDisplayFullEmail;
+- (void) setMailDisplayFullEmail: (BOOL) newValue;
+- (BOOL) mailDisplayFullEmail;
 
 - (void) setMailDisplayRemoteInlineImages: (NSString *) newValue;
 - (NSString *) mailDisplayRemoteInlineImages;
 
+- (void) setMailDisplayAttachmentAbove: (BOOL) newValue;
+- (BOOL) mailDisplayAttachmentAbove;
 
 - (void) setMailAutoMarkAsReadDelay: (int) newValue;
 - (int) mailAutoMarkAsReadDelay;
