@@ -33,8 +33,11 @@
 - (BOOL) isICal;
 - (BOOL) isICal4;
 - (BOOL) isMacOSXAddressBookApp;
+- (BOOL) isMacOSXCalendarApp;
 - (BOOL) isIPhoneAddressBookApp;
 - (BOOL) isAndroid;
+- (BOOL) isMacOSXCalendar;
+- (BOOL) isThunderbird;
 
 @end
 
