@@ -11,6 +11,7 @@ import {
   propfind,
 
   calendarMultiGet,
+  calendarQuery,
   createCalendarObject,
   makeCalendar,
 
@@ -408,6 +409,19 @@ class WebDAV {
     })
   }
 
+  calendarQuery(resource, filters) {
+    return calendarQuery({
+      url: this.serverUrl + resource,
+      headers: this.headers,
+      depth: '1',
+      props: [
+        { name: 'getetag', namespace: DAVNamespace.DAV },
+        { name: 'calendar-data', namespace: DAVNamespace.CALDAV },
+      ],
+      filters,
+    })
+  }
+
   calendarMultiGet(resource, filename) {
     return calendarMultiGet({
       url: this.serverUrl + resource,
