@@ -2,6 +2,10 @@ import config from '../lib/config'
 import WebDAV from '../lib/WebDAV'
 import TestUtility from '../lib/utilities'
 
+beforeAll(function () {
+  jasmine.DEFAULT_TIMEOUT_INTERVAL = config.timeout || 10000;
+});
+
 describe('DAVCalendarSuperUserAcl', function() {
   const webdav = new WebDAV(config.username, config.password)
   const webdav_su = new WebDAV(config.superuser, config.superuser_password)
