@@ -1,6 +1,6 @@
 /* SOGoToolBackup.m - this file is part of SOGo
  *
- * Copyright (C) 2009-2016 Inverse inc.
+ * Copyright (C) 2009-2020 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -168,7 +168,7 @@
               if (user)
                 [allSqlUsers addObject: user];
             }
-          [cm releaseChannel: fc];
+          [cm releaseChannel: fc  immediately: YES];
 
           users = allSqlUsers;
           max = [users count];
@@ -270,7 +270,7 @@
       row = [fc fetchAttributes: attrs withZone: NULL];
       displayName = [row objectForKey: @"c_foldername"];
       [fc cancelFetch];
-      [cm releaseChannel: fc];
+      [cm releaseChannel: fc  immediately: YES];
     }
 
   if (!displayName)
