@@ -1,8 +1,6 @@
 /* UIxAclEditor.h - this file is part of SOGo
  *
- * Copyright (C) 2006, 2007 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2006-2014 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,16 +29,20 @@
   BOOL publishInFreeBusy;
   NSArray *aclUsers;
   NSArray *savedUIDs;
-  NSMutableArray *users;
+  NSMutableDictionary *users;
   NSString *currentUser;
   NSString *defaultUserID;
 }
 
 - (NSArray *) aclsForObject;
 
-- (NSArray *) usersForObject;
 - (void) setCurrentUser: (NSString *) newCurrentUser;
 - (NSString *) currentUser;
+- (NSString *) currentUserClass;
+- (NSDictionary *) currentUserInfos;
+- (NSString *) currentUserDisplayName;
+- (BOOL) currentUserIsSubscribed;
+- (BOOL) isPublicAccessEnabled;
 
 @end
 
