@@ -488,13 +488,14 @@
 	  && [user isSuperUser]);
 }
 
-- (BOOL) usesCASAuthentication
+
+- (BOOL) usesOpenIdAuthentication
 {
   SOGoSystemDefaults *sd;
 
   sd = [SOGoSystemDefaults sharedSystemDefaults];
 
-  return [[sd authenticationType] isEqualToString: @"cas"];
+  return [[sd authenticationType] isEqualToString: @"openid"];
 }
 
 - (BOOL) usesSAML2Authenticationx
@@ -537,19 +538,34 @@
   BOOL canLogoff;
   id auth;
   SOGoSystemDefaults *sd;
-  NSString *authType;
+  NSString *authType, *login, *loginDomain;
+  NSRange r;
 
   auth = [[self clientObject] authenticatorInContext: context];
   if ([auth respondsToSelector: @selector (cookieNameInContext:)])
     {
+
       sd = [SOGoSystemDefaults sharedSystemDefaults];
-      authType = [sd authenticationType];
-      if ([authType isEqualToString: @"cas"])
-	canLogoff = [sd CASLogoutEnabled];
-      else if ([authType isEqualToString: @"saml2"])
-	canLogoff = [sd SAML2LogoutEnabled];
+
+      login = [[context activeUser] login];
+      r = [login rangeOfString: @"@"];
+      if (r.location != NSNotFound)
+        loginDomain = [login substringFromIndex: r.location+1];
       else
-	canLogoff = [[auth cookieNameInContext: context] length] > 0;
+        loginDomain = nil;
+      if(loginDomain && [sd doesLoginTypeByDomain])
+        authType = [sd getLoginTypeForDomain: loginDomain];
+      else
+        authType = [sd authenticationType];
+
+      if ([authType isEqualToString: @"cas"])
+	      canLogoff = [sd CASLogoutEnabled];
+      else if ([authType isEqualToString: @"saml2"])
+	      canLogoff = [sd SAML2LogoutEnabled];
+      else if ([authType isEqualToString: @"openid"])
+	      canLogoff = [sd openIdLogoutEnabled: loginDomain];
+      else
+	      canLogoff = [[auth cookieNameInContext: context] length] > 0;
     }
   else
     canLogoff = NO;
