@@ -240,6 +240,7 @@ static Class SOGoContactGCSEntryK = Nil;
   NSCalendarDate *date;
   CardElement *element;
   id o;
+  BOOL hasCertificate;
 
   unsigned int i, year, month, day;
 
@@ -418,6 +419,10 @@ static Class SOGoContactGCSEntryK = Nil;
         }
     }
 
+  hasCertificate = [[attributes objectForKey: @"hasCertificate"] boolValue];
+  if (!hasCertificate)
+    [card setCertificate: nil];
+
   [card cleanupEmptyChildren];
 }
 
