@@ -23,8 +23,9 @@
 #include <openssl/ssl.h>
 #include <openssl/bio.h>
 #include <openssl/err.h>
-#include <openssl/pkcs7.h>
+#include <openssl/cms.h>
 #include <openssl/x509.h>
+#include <openssl/x509v3.h>
 #endif
 
 #import <Foundation/NSDictionary.h>
@@ -96,11 +97,12 @@
 - (NSData *) _processMessageWith: (NSData *) signedData
 {
   NSData *output;
+  NSMutableArray *emails;
 
   STACK_OF(X509) *certs;
   X509_STORE *x509Store;
-  BIO *msgBio, *obio;
-  PKCS7 *p7;
+  BIO *msgBio, *obio = NULL;
+  CMS_ContentInfo *cms;
   int err, i;
 
   ERR_clear_error();
@@ -108,32 +110,44 @@
   msgBio = BIO_new_mem_buf ((void *) [signedData bytes], [signedData length]);
   output = NULL;
 
-  p7 = SMIME_read_PKCS7(msgBio, NULL);
+  cms = SMIME_read_CMS(msgBio, NULL);
 
   certs = NULL;
   certificates = [NSMutableArray array];
+  emails = [NSMutableArray array];
   validationMessage = nil;
 
-  if (p7)
+  if (cms)
     {
-      if (OBJ_obj2nid(p7->type) == NID_pkcs7_signed)
+      if (OBJ_obj2nid(CMS_get0_type(cms)) == NID_pkcs7_signed)
 	{
           NSString *subject, *issuer;
 	  X509 *x;
 
-	  certs = p7->d.sign->cert;
+	  BIO *dummybio = BIO_new(BIO_s_mem());
+	  CMS_verify(cms, NULL, NULL, dummybio, NULL, CMS_NO_SIGNER_CERT_VERIFY | CMS_NO_ATTR_VERIFY | CMS_NO_CONTENT_VERIFY);
+	  ERR_clear_error();
+	  BIO_free(dummybio);
+	  certs = CMS_get0_signers(cms);
 
           for (i = 0; i < sk_X509_num(certs); i++)
             {
 	      BIO *buf;
 	      char p[1024];
+	      int j;
+	      STACK_OF(OPENSSL_STRING) *emlst;
 
 	      x = sk_X509_value(certs, i);
 
+	      emlst = X509_get1_email(x);
+	      for (j = 0; j < sk_OPENSSL_STRING_num(emlst); j++)
+	          [emails addObject: [[NSString stringWithUTF8String: sk_OPENSSL_STRING_value(emlst, j)] lowercaseString]];
+	      X509_email_free(emlst);
+
 	      memset(p, 0, 1024);
 	      buf = BIO_new(BIO_s_mem());
 	      X509_NAME_print_ex(buf, X509_get_subject_name(x), 0,
-                                 ASN1_STRFLGS_ESC_CTRL | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
+                                 ASN1_STRFLGS_ESC_CTRL | ASN1_STRFLGS_UTF8_CONVERT | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
               BIO_read(buf, p, 1024);
 	      subject = [NSString stringWithUTF8String: p];
 	      BIO_free(buf);
@@ -141,7 +155,7 @@
 	      memset(p, 0, 1024);
 	      buf = BIO_new(BIO_s_mem());
 	      X509_NAME_print_ex(buf, X509_get_issuer_name(x), 0,
-                                 ASN1_STRFLGS_ESC_CTRL | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
+                                 ASN1_STRFLGS_ESC_CTRL | ASN1_STRFLGS_UTF8_CONVERT | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
 	      BIO_read(buf, p, 1024);
 	      issuer = [NSString stringWithUTF8String: p];
 	      BIO_free(buf);
@@ -161,7 +175,7 @@
           x509Store = [self _setupVerify];
           obio = BIO_new(BIO_s_mem());
 
-	  validSignature = (PKCS7_verify(p7, NULL, x509Store, NULL,
+	  validSignature = (CMS_verify(cms, NULL, x509Store, NULL,
 					 obio, 0) == 1);
 
 	  err = ERR_get_error();
@@ -204,48 +218,19 @@
         }
     }
 
-  PKCS7_free(p7);
+  CMS_ContentInfo_free(cms);
   BIO_free (msgBio);
   BIO_free (obio);
 
   if (validSignature)
     {
-      BOOL hasMatchingAddress;
-      NSArray *pair;
-      NSDictionary *certificate, *values;
-      NSEnumerator *certificatesList, *subjectList;
-      NSString *senderAddress, *label, *value;
+      NSString *senderAddress;
 
       validationMessage = [self labelForKey: @"Message is signed"];
-      hasMatchingAddress = NO;
-      value = nil;
       senderAddress = [[[[[self clientObject] fromEnvelopeAddresses] lastObject] baseEMail] lowercaseString];
-      certificatesList = [certificates objectEnumerator];
-      while ((certificate = [certificatesList nextObject]) && !hasMatchingAddress)
+      if (![emails containsObject: senderAddress])
         {
-          subjectList = [[certificate objectForKey: @"subject"] objectEnumerator];
-          while ((pair = [subjectList nextObject]) && !hasMatchingAddress)
-            {
-              label = [[pair objectAtIndex: 0] lowercaseString];
-              value = [[pair objectAtIndex: 1] lowercaseString];
-              if ([label isEqualToString: @"commonname"] && [value isEqualToString: senderAddress])
-                {
-                  hasMatchingAddress = 1;
-                }
-            }
-        }
-
-      if (!hasMatchingAddress)
-        {
-          if (value)
-            {
-              values = [NSDictionary dictionaryWithObjectsAndKeys: value, @"certificateCn", nil];
-              validationMessage = [values keysWithFormat: [self labelForKey: @"Message is signed but the certificate (%{certificateCn}) doesn't match the sender email address"]];
-            }
-          else
-            {
-              validationMessage = [self labelForKey: @"Message is signed but the certificate doesn't match the sender email address"];
-            }
+          validationMessage = [self labelForKey: @"Message is signed but the certificate doesn't match the sender email address"];
         }
     }
   else if (!validationMessage)
