@@ -21,8 +21,9 @@
 #if defined(HAVE_OPENSSL) || defined(HAVE_GNUTLS)
 #include <openssl/bio.h>
 #include <openssl/err.h>
-#include <openssl/pkcs7.h>
+#include <openssl/cms.h>
 #include <openssl/x509.h>
+#include <openssl/x509v3.h>
 #endif
 
 #import <Foundation/NSData.h>
@@ -93,11 +94,12 @@
 - (void) _processMessage
 {
   NSData *signedData;
+  NSMutableArray *emails;
   
   STACK_OF(X509) *certs;
   X509_STORE *x509Store;
   BIO *msgBio, *inData;
-  PKCS7 *p7;
+  CMS_ContentInfo *cms;
   int err, i;
  
   ERR_clear_error();
@@ -110,32 +112,44 @@
   msgBio = BIO_new_mem_buf ((void *) [signedData bytes], [signedData length]);
 
   inData = NULL;
-  p7 = SMIME_read_PKCS7(msgBio, &inData);
+  cms = SMIME_read_CMS(msgBio, &inData);
 
   certs = NULL;
   certificates = [NSMutableArray array];
+  emails = [NSMutableArray array];
   validationMessage = nil;
 
-  if (p7)
+  if (cms)
     {
-      if (OBJ_obj2nid(p7->type) == NID_pkcs7_signed)
+      if (OBJ_obj2nid(CMS_get0_type(cms)) == NID_pkcs7_signed)
 	{
           NSString *subject, *issuer;
 	  X509 *x;
 	  
-	  certs = PKCS7_get0_signers(p7, NULL, 0);
+	  BIO *dummybio = BIO_new(BIO_s_mem());
+	  CMS_verify(cms, NULL, NULL, dummybio, NULL, CMS_NO_SIGNER_CERT_VERIFY | CMS_NO_ATTR_VERIFY | CMS_NO_CONTENT_VERIFY);
+	  ERR_clear_error();
+	  BIO_free(dummybio);
+	  certs = CMS_get0_signers(cms);
 
           for (i = 0; i < sk_X509_num(certs); i++)
             {
 	      BIO *buf;
 	      char p[1024];
+	      int j;
+	      STACK_OF(OPENSSL_STRING) *emlst;
 
 	      x = sk_X509_value(certs, i);
 
+	      emlst = X509_get1_email(x);
+	      for (j = 0; j < sk_OPENSSL_STRING_num(emlst); j++)
+	          [emails addObject: [[NSString stringWithUTF8String: sk_OPENSSL_STRING_value(emlst, j)] lowercaseString]];
+	      X509_email_free(emlst);
+
 	      memset(p, 0, 1024);
 	      buf = BIO_new(BIO_s_mem());
 	      X509_NAME_print_ex(buf, X509_get_subject_name(x), 0,
-                                 ASN1_STRFLGS_ESC_CTRL | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
+                                 ASN1_STRFLGS_ESC_CTRL | ASN1_STRFLGS_UTF8_CONVERT | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
               BIO_read(buf, p, 1024);
 	      subject = [NSString stringWithUTF8String: p];
 	      BIO_free(buf);
@@ -143,13 +157,14 @@
 	      memset(p, 0, 1024);
 	      buf = BIO_new(BIO_s_mem());
 	      X509_NAME_print_ex(buf, X509_get_issuer_name(x), 0,
-                                 ASN1_STRFLGS_ESC_CTRL | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
+                                 ASN1_STRFLGS_ESC_CTRL | ASN1_STRFLGS_UTF8_CONVERT | XN_FLAG_SEP_MULTILINE | XN_FLAG_FN_LN);
 	      BIO_read(buf, p, 1024);
 	      issuer = [NSString stringWithUTF8String: p];
 	      BIO_free(buf);
 
               [certificates addObject: [self certificateForSubject: subject
-                                                         andIssuer: issuer]];
+                                                         andIssuer: issuer
+                                                        withEmails: emails]];
 	    }
 	}
       
@@ -161,7 +176,7 @@
       else
 	{
 	  x509Store = [self _setupVerify];
-	  validSignature = (PKCS7_verify(p7, NULL, x509Store, inData,
+	  validSignature = (CMS_verify(cms, NULL, x509Store, inData,
 					 NULL, PKCS7_DETACHED) == 1);
 	  
 	  err = ERR_get_error();
@@ -194,6 +209,7 @@
     }
 
   
+  CMS_ContentInfo_free(cms);
   BIO_free (msgBio);
   if (inData)
     BIO_free (inData);
@@ -201,46 +217,15 @@
   
   if (validSignature)
     {
-      BOOL hasMatchingAddress;
-      NSArray *pair, *attributes;
-      NSDictionary *certificate, *values;
-      NSEnumerator *certificatesList, *subjectList;
-      NSString *senderAddress, *label, *value;
+      NSString *senderAddress;
 
       // See https://datatracker.ietf.org/doc/html/rfc8550#section-3
       // See https://datatracker.ietf.org/doc/html/rfc8550#section-4.4.3
-      // TODO: handle multiple email addresses in SubjectAltName
-      attributes = [NSArray arrayWithObjects: @"commonname", @"subjectaltname", @"emailaddress", nil];
       validationMessage = [self labelForKey: @"Message is signed"];
-      hasMatchingAddress = NO;
-      value = nil;
       senderAddress = [[[[[self clientObject] fromEnvelopeAddresses] lastObject] baseEMail] lowercaseString];
-      certificatesList = [certificates objectEnumerator];
-      while ((certificate = [certificatesList nextObject]) && !hasMatchingAddress)
+      if (![emails containsObject: senderAddress])
         {
-          subjectList = [[certificate objectForKey: @"subject"] objectEnumerator];
-          while ((pair = [subjectList nextObject]) && !hasMatchingAddress)
-            {
-              label = [[pair objectAtIndex: 0] lowercaseString];
-              value = [[pair objectAtIndex: 1] lowercaseString];
-              if ([attributes containsObject: label] && [value isEqualToString: senderAddress])
-                {
-                  hasMatchingAddress = 1;
-                }
-            }
-        }
-
-      if (!hasMatchingAddress)
-        {
-          if (value)
-            {
-              values = [NSDictionary dictionaryWithObjectsAndKeys: value, @"certificateCn", nil];
-              validationMessage = [values keysWithFormat: [self labelForKey: @"Message is signed but the certificate (%{certificateCn}) doesn't match the sender email address"]];
-            }
-          else
-            {
-              validationMessage = [self labelForKey: @"Message is signed but the certificate doesn't match the sender email address"];
-            }
+          validationMessage = [self labelForKey: @"Message is signed but the certificate doesn't match the sender email address"];
         }
     }
   else if (!validationMessage)
@@ -261,10 +246,12 @@
 
 - (NSDictionary *) certificateForSubject: (NSString *) subject
                                andIssuer: (NSString *) issuer
+                              withEmails: (NSArray *) emails
 {
   return [NSDictionary dictionaryWithObjectsAndKeys:
-                              [subject componentsFromMultilineDN], @"subject",
-                              [issuer componentsFromMultilineDN], @"issuer",
+                         [subject componentsFromMultilineDN], @"subject",
+                         [issuer componentsFromMultilineDN], @"issuer",
+                         emails, @"emails",
                        nil];
 }
 
