@@ -54,6 +54,7 @@
       attachmentIds = nil;
       flatContent = nil;
       decodedContent = nil;
+      _shouldDisplayAttachment = YES;
     }
 
   return self;
@@ -189,22 +190,39 @@
 
 - (id) renderedPart
 {
-  NSString *type;
+  NSString *type, *content;
+  NSException *e;
+  NSMutableDictionary *r;
 
+  e = nil;
   type = [NSString stringWithFormat: @"%@/%@",
                             [bodyInfo objectForKey: @"type"],
                             [bodyInfo objectForKey: @"subtype"]];
+  
 
-  return [NSDictionary dictionaryWithObjectsAndKeys:
+
+  content = [[[self generateResponse] contentAsString] stringWithoutHTMLInjection: NO];
+  if ([self respondsToSelector:@selector(getException)]) {
+    e = [self getException];
+  }
+  
+
+  r = [NSMutableDictionary dictionaryWithObjectsAndKeys:
                          [self className], @"type",
                        type, @"contentType",
-                       [[[self generateResponse] contentAsString] stringWithoutHTMLInjection: NO], @"content",
+                       content, @"content",
                        [self filenameForDisplay], @"filename",
                        [self preferredPathExtension], @"extension",
                        [[self sizeFormatter] stringForObjectValue: [bodyInfo objectForKey: @"size"]], @"size",
                        [self pathToAttachment], @"viewURL",
                        [self pathForDownload], @"downloadURL",
+                       [NSNumber numberWithBool:_shouldDisplayAttachment], @"shouldDisplayAttachment",
                        nil];
+  if (e) {
+    [r setObject: [e userInfo] forKey: @"exception"];
+  }
+  
+  return r;
 }
 
 - (NSDictionary *) attachmentIds
@@ -222,6 +240,12 @@
   attachmentIds = newAttachmentIds;
 }
 
+- (void) setAttachmentIds:(NSDictionary *)newAttachmentIds displayAttachment:(BOOL)shouldDisplayAttachment
+{
+  [self setAttachmentIds: newAttachmentIds];
+  _shouldDisplayAttachment = shouldDisplayAttachment;
+}
+
 - (NSString *) flatContentAsString
 {
   NSString *charset, *s;
