@@ -42,6 +42,7 @@
 #import <SOGo/NSDictionary+Utilities.h>
 #import <SOGo/NSString+Utilities.h>
 #import <SOGo/WOResourceManager+SOGo.h>
+#import <SOGo/NGMimeBodyPart+SOGo.h>
 #import <SOGoUI/UIxComponent.h>
 #import <Mailer/SOGoDraftObject.h>
 #import <Mailer/SOGoMailObject+Draft.h>
@@ -65,7 +66,6 @@
   NSString *sourceUID;
   NSString *sourceFolder;
   NSString *text;
-  NSMutableArray *fromEMails;
   NSString *from;
   SOGoMailFolder *sentFolder;
   BOOL isHTML;
@@ -122,7 +122,6 @@ static NSArray *infoKeys = nil;
   [priority release];
   [receipt release];
   [sentFolder release];
-  [fromEMails release];
   [from release];
   [text release];
   [subject release];
@@ -203,11 +202,6 @@ static NSArray *infoKeys = nil;
   return [[ud mailComposeMessageType] isEqualToString: @"html"];
 }
 
-- (NSString *) editorClass
-{
-  return ([self isHTML]? @"ck-editor" : @"plain-text");
-}
-
 - (NSString *) itemPriorityText
 {
   return [self labelForKey: [NSString stringWithFormat: @"%@", [item lowercaseString]]];
@@ -258,10 +252,10 @@ static NSArray *infoKeys = nil;
   NSRange r;
   BOOL valid;
 
-  identities = [[[self clientObject] mailAccountFolder] identities];
-  if ([identities count])
+  if ([from length])
     {
-      if (from)
+      identities = [[[self clientObject] mailAccountFolder] identities];
+      if ([identities count])
         {
           allIdentities = [identities objectEnumerator];
           valid = NO;
@@ -283,11 +277,6 @@ static NSArray *infoKeys = nil;
               from = nil;
             }
         }
-      if (!from)
-        {
-          from = [self _emailFromIdentity: [identities objectAtIndex: 0]];
-          [from retain];
-        }
     }
 
   return from;
@@ -306,19 +295,11 @@ static NSArray *infoKeys = nil;
   //
   if ([[[[self clientObject] mailAccountFolder] nameInContainer] intValue] == 0)
     {
-      SOGoUserDefaults *ud;
-      
-      ud = [[context activeUser] userDefaults];
-      value = [ud mailReplyTo];
+      value = [[[context activeUser] defaultIdentity] objectForKey: @"replyTo"];
     }
   else
     {
-      NSArray *identities;
-      
-      identities = [[[self clientObject] mailAccountFolder] identities];
-
-      if ([identities count])
-        value = [[identities objectAtIndex: 0] objectForKey: @"replyTo"];
+      value = [[[[self clientObject] mailAccountFolder] defaultIdentity] objectForKey: @"replyTo"];
     }
 
   return value;
@@ -372,7 +353,7 @@ static NSArray *infoKeys = nil;
   if ([newTo isKindOfClass: [NSNull class]])
     newTo = nil;
 
-  ASSIGN (to, newTo);
+  ASSIGN (to, [newTo uniqueObjects]);
 }
 
 - (NSArray *) to
@@ -385,7 +366,7 @@ static NSArray *infoKeys = nil;
   if ([newCc isKindOfClass: [NSNull class]])
     newCc = nil;
 
-  ASSIGN (cc, newCc);
+  ASSIGN (cc, [newCc uniqueObjects]);
 }
 
 - (NSArray *) cc
@@ -398,7 +379,7 @@ static NSArray *infoKeys = nil;
   if ([newBcc isKindOfClass: [NSNull class]])
     newBcc = nil;
 
-  ASSIGN (bcc, newBcc);
+  ASSIGN (bcc, [newBcc uniqueObjects]);
 }
 
 - (NSArray *) bcc
@@ -426,31 +407,6 @@ static NSArray *infoKeys = nil;
   return [UIxMailSizeFormatter sharedMailSizeFormatter];
 }
 
-/* from addresses */
-
-- (NSArray *) fromEMails
-{
-  NSArray *identities;
-  int count, max;
-  NSString *email;
-  SOGoMailAccount *account;
-
-  if (!fromEMails)
-    { 
-      account = [[self clientObject] mailAccountFolder];
-      identities = [account identities];
-      max = [identities count];
-      fromEMails = [[NSMutableArray alloc] initWithCapacity: max];
-      for (count = 0; count < max; count++)
-        {
-          email = [self _emailFromIdentity: [identities objectAtIndex: count]];
-          [fromEMails addObjectUniquely: email];
-        }
-    }
-
-  return fromEMails;
-}
-
 /* info loading */
 
 - (void) loadInfo: (NSDictionary *) _info
@@ -570,10 +526,9 @@ static NSArray *infoKeys = nil;
   return newFilename;
 }
 
-- (NSDictionary *) _scanAttachmentFilenamesInRequest: (id) httpBody
+- (NSMutableDictionary *) _scanAttachmentFilenamesInRequest: (id) httpBody
 {
-  NSMutableDictionary *files;
-  NSDictionary *file;
+  NSMutableDictionary *files, *file;
   NSArray *parts;
   unsigned int count, max;
   NGMimeBodyPart *part;
@@ -592,11 +547,11 @@ static NSArray *infoKeys = nil;
         {
           mimeType = [(NGMimeType *)[part headerForKey: @"content-type"] stringValue];
           filename = [self _fixedFilename: [header filename]];
-          file = [NSDictionary dictionaryWithObjectsAndKeys:
-                                 filename, @"filename",
-                                 mimeType, @"mimetype",
-                                 [part body], @"body",
-                                 nil];
+          file = [NSMutableDictionary dictionaryWithObjectsAndKeys:
+                                      filename, @"filename",
+                                      mimeType, @"mimetype",
+                                      [part body], @"body",
+                                      nil];
           [files setObject: file forKey: [NSString stringWithFormat: @"%@_%@", [header name], filename]];
         }
     }
@@ -609,7 +564,8 @@ static NSArray *infoKeys = nil;
   NSException *error;
   WORequest *request;
   NSEnumerator *allAttachments;
-  NSDictionary *attrs, *filenames;
+  NSMutableDictionary *attrs;
+  NSDictionary *filenames;
   id httpBody;
   SOGoDraftObject *co;
 
@@ -645,11 +601,12 @@ static NSArray *infoKeys = nil;
 {
   NSDictionary *info;
   NSException *error;
-  NSString *fontSize, *content;
+  NSString *content;
   NGMimeType *mimeType;
   WORequest *request;
   SOGoDraftObject *co;
   SOGoUserDefaults *ud;
+  int fontSize;
 
   error = nil;
   request = [context request];
@@ -674,8 +631,8 @@ static NSArray *infoKeys = nil;
           // Set a base font size if mail is HTML and user has set a default font-size
           ud = [[context activeUser] userDefaults];
           fontSize = [ud mailComposeFontSize];
-          if ([fontSize intValue] > 0)
-            content = [NSString stringWithFormat: @"<html><span style=\"font-size: %@px;\">%@</span></html>",
+          if (fontSize > 0)
+            content = [NSString stringWithFormat: @"<html><span style=\"font-size: %ipx;\">%@</span></html>",
                                 fontSize, text];
           else
             content = [NSString stringWithFormat: @"<html>%@</html>", text];
@@ -746,6 +703,51 @@ static NSArray *infoKeys = nil;
   return [[self attachmentAttrs] count] > 0 ? YES : NO;
 }
 
+/*
+ * This method replace cid images in body with base64 inline image data
+ */
+- (void) setBase64ImagesInText:(SOGoDraftObject *) draft
+{
+  NSString *contentId, *lText;
+  NGMimeBodyPart *mime;
+
+  if ([self isHTML] && [[draft fetchAttachmentAttrs] count] > 0) {
+        for (NSDictionary *draftFileAttachement in [draft fetchAttachmentAttrs]) {
+          mime = [draftFileAttachement objectForKey: @"part"];
+          if ([mime isImage]) {
+            contentId = [mime contentId];
+            if (contentId) {
+              contentId = [contentId stringByReplacingOccurrencesOfString: @"<" withString: @"cid:"];
+              contentId = [contentId stringByReplacingOccurrencesOfString: @">" withString: @""];
+
+              if ([[mime encoding] isEqualToString: @"base64"] && contentId) {
+                if ([text rangeOfString: contentId].location != NSNotFound) {
+                  if (nil != [[mime body] bytes]) {
+                    lText = [text stringByReplacingOccurrencesOfString: contentId 
+                    withString: [NSString stringWithFormat: @"data:%@;base64,%@", 
+                    [[mime contentType] stringValue], 
+                    [NSString stringWithUTF8String: [[mime body] bytes]]]];
+                    [self setText: lText];
+                    [draft deleteAttachmentWithName: [draftFileAttachement objectForKey:@"filename"]];
+                  }
+                } else {
+                  // This is an attachment with no CID in message body
+                  if ([draft inReplyTo]) {
+                    // If the image has no CID and the draft is a reply (not forward, the images in attachement should be removed)
+                    [draft deleteAttachmentWithName: [draftFileAttachement objectForKey:@"filename"]];
+                  }
+                }
+              } else {
+                [self warnWithFormat: @"Empty content id [1] : %@", contentId];
+              }
+            } else {
+              [self warnWithFormat: @"Empty content id [2] : %@", contentId];
+            }
+          }
+        }                  
+    }
+}
+
 - (id <WOActionResults>) editAction
 {
   id <WOActionResults> response;
@@ -762,11 +764,11 @@ static NSArray *infoKeys = nil;
   [self setSourceFolder: [co sourceFolder]];
 
   data = [NSMutableDictionary dictionaryWithObjectsAndKeys:
-                              [self from], @"from",
                               [self localeCode], @"locale",
                               [NSNumber numberWithBool: [self isHTML]], @"isHTML",
-                              text, @"text",
                               nil];
+  if ((value = [self from]))
+    [data setObject: value forKey: @"from"];
   if ((value = [self replyTo]))
     [data setObject: value forKey: @"replyTo"];
   if ((value = [self to]))
@@ -780,6 +782,10 @@ static NSArray *infoKeys = nil;
   if ((value = [self attachmentAttrs]))
     [data setObject: value forKey: @"attachmentAttrs"];
 
+  [self setBase64ImagesInText: co];
+  [data setObject: text forKey: @"text"];
+    
+
   response = [self responseWithStatus: 200
                             andString: [data jsonRepresentation]];
 
@@ -877,7 +883,7 @@ static NSArray *infoKeys = nil;
                                                   [self labelForKey: @"Tried to send too many mails. Please wait."],
                                        @"message",
                                        nil];
-          return [self responseWithStatus: 200
+          return [self responseWithStatus: 405
                                 andString: [jsonResponse jsonRepresentation]];
         }
       
