@@ -1,6 +1,6 @@
 /* UIxMailFolderActions.h - this file is part of SOGo
  *
- * Copyright (C) 2007-2016 Inverse inc.
+ * Copyright (C) 2007-2021 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,9 +33,12 @@
 - (WOResponse *) batchDeleteAction;
 - (WOResponse *) saveMessagesAction;
 - (WOResponse *) expungeAction;
+- (WOResponse *) emptyJunkAction;
 - (WOResponse *) emptyTrashAction;
+- (WOResponse *) emptySpecialFolderAction: (NSString *) folderType;
 - (WOResponse *) subscribeAction;
 - (WOResponse *) unsubscribeAction;
+- (id <WOActionResults>) getLabelsAction;
 
 @end
 
