@@ -370,6 +370,16 @@
 @implementation SOGoACLKazakhRemovalAdvisory
 @end
 
+@implementation SOGoACLKoreanModificationAdvisory
+@end
+
+@implementation SOGoACLKoreanAdditionAdvisory
+@end
+
+@implementation SOGoACLKoreanRemovalAdvisory
+@end
+
+
 @implementation SOGoACLNorwegianBokmalAdditionAdvisory
 @end
 
@@ -433,3 +443,11 @@
 @implementation SOGoACLSwedishRemovalAdvisory
 @end
 
+@implementation SOGoACLThaiAdditionAdvisory
+@end
+
+@implementation SOGoACLThaiModificationAdvisory
+@end
+
+@implementation SOGoACLThaiRemovalAdvisory
+@end
