@@ -161,6 +161,12 @@
 @interface SOGoFolderKazakhRemovalAdvisory : SOGoFolderRemovalAdvisory
 @end
 
+@interface SOGoFolderKoreanAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderKoreanRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
 @interface SOGoFolderLatvianAdditionAdvisory : SOGoFolderAdditionAdvisory
 @end
 
@@ -245,4 +251,10 @@
 @interface SOGoFolderSwedishRemovalAdvisory : SOGoFolderRemovalAdvisory
 @end
 
+@interface SOGoFolderThaiAdditionAdvisory : SOGoFolderAdditionAdvisory
+@end
+
+@interface SOGoFolderThaiRemovalAdvisory : SOGoFolderRemovalAdvisory
+@end
+
 #endif /* SOGOFOLDERADVISORY_H */
