@@ -334,6 +334,12 @@
 @implementation SOGoFolderKazakhRemovalAdvisory
 @end
 
+@implementation SOGoFolderKoreanAdditionAdvisory
+@end
+
+@implementation SOGoFolderKoreanRemovalAdvisory
+@end
+
 @implementation SOGoFolderLatvianAdditionAdvisory
 @end
 
@@ -417,3 +423,9 @@
 
 @implementation SOGoFolderSwedishRemovalAdvisory
 @end
+
+@implementation SOGoFolderThaiAdditionAdvisory
+@end
+
+@implementation SOGoFolderThaiRemovalAdvisory
+@end
