@@ -1,8 +1,6 @@
 /* NSArray+Scheduler.m - this file is part of SOGo
  *
- * Copyright (C) 2007-2010 Inverse inc.
- *
- * Author: Wolfgang Sourdeau <wsourdeau@inverse.ca>
+ * Copyright (C) 2007-2016 Inverse inc.
  *
  * This file is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,30 +21,32 @@
 #ifndef	NSARRAY_SCHEDULER_H
 #define	NSARRAY_SCHEDULER_H
 
-#import <Foundation/NSArray.h>
 
 // See [UIxCalListingActions initialize]
 #define eventNameIndex              0
 #define eventFolderIndex            1
 #define eventCalendarNameIndex      2
 #define eventStatusIndex            3
-#define eventTitleIndex             4
-#define eventStartDateIndex         5
-#define eventEndDateIndex           6
-#define eventLocationIndex          7
-#define eventIsAllDayIndex          8
-#define eventClassificationIndex    9
-#define eventCategoryIndex         10
-#define eventPartMailsIndex        11
-#define eventPartStatesIndex       12
-#define eventOwnerIndex            13
-#define eventIsCycleIndex          14
-#define eventNextAlarmIndex        15
-#define eventRecurrenceIdIndex     16
-#define eventIsExceptionIndex      17
-#define eventEditableIndex         18
-#define eventErasableIndex         19
-#define eventOwnerIsOrganizerIndex 20
+#define eventIsOpaqueIndex          4
+#define eventTitleIndex             5
+#define eventStartDateIndex         6
+#define eventStartHourIndex         7
+#define eventEndDateIndex           8
+#define eventLocationIndex          9
+#define eventIsAllDayIndex         10
+#define eventClassificationIndex   11
+#define eventCategoryIndex         12
+#define eventPriorityIndex         13
+#define eventPartMailsIndex        14
+#define eventPartStatesIndex       15
+#define eventOwnerIndex            16
+#define eventIsCycleIndex          17
+#define eventNextAlarmIndex        18
+#define eventRecurrenceIdIndex     19
+#define eventIsExceptionIndex      20
+#define eventEditableIndex         21
+#define eventErasableIndex         22
+#define eventOwnerIsOrganizerIndex 23
 
 // See [UIxCalListingActions initialize]
 #define taskNameIndex               0
@@ -54,13 +54,22 @@
 #define taskCalendarNameIndex       2
 #define taskStatusIndex             3
 #define taskTitleIndex              4
-#define taskEndDateIndex            5
-#define taskClassificationIndex     6
-#define taskLocationIndex           7
-#define taskCategoryIndex           8
-#define taskEditableIndex           9
-#define taskErasableIndex          10
-#define taskPriorityIndex          11
+#define taskStartDateIndex          5
+#define taskEndDateIndex            6
+#define taskClassificationIndex     7
+#define taskLocationIndex           8
+#define taskCategoryIndex           9
+#define taskViewableIndex          10
+#define taskEditableIndex          11
+#define taskErasableIndex          12
+#define taskPriorityIndex          13
+#define taskOwnerIndex             14
+#define taskIsCycleIndex           15
+#define taskNextAlarmIndex         16
+#define taskRecurrenceIdIndex      17
+#define taskIsExceptionIndex       18
+#define taskDescriptionIndex       19
+#define taskStatusFlagIndex        20
 
 @interface NSArray (SOGoEventComparison)
 
@@ -72,7 +81,8 @@
 - (NSComparisonResult) compareTasksAscending: (NSArray *) otherTask;
 - (NSComparisonResult) compareTasksPriorityAscending: (NSArray *) otherTask;
 - (NSComparisonResult) compareTasksTitleAscending: (NSArray *) otherTask;
-- (NSComparisonResult) compareTasksEndAscending: (NSArray *) otherTask;
+- (NSComparisonResult) compareTasksStartDateAscending: (NSArray *) otherTask;
+- (NSComparisonResult) compareTasksEndDateAscending: (NSArray *) otherTask;
 - (NSComparisonResult) compareTasksLocationAscending: (NSArray *) otherTask;
 - (NSComparisonResult) compareTasksCategoryAscending: (NSArray *) otherTask;
 - (NSComparisonResult) compareTasksCalendarNameAscending: (NSArray *) otherTask;
