@@ -4,7 +4,7 @@
 (function() {
   'use strict';
 
-  angular.module('SOGo.AdministrationUI', ['ui.router', 'SOGo.Common', 'SOGo.Authentication', 'SOGo.PreferencesUI', 'SOGo.ContactsUI', 'SOGo.SchedulerUI'])
+  angular.module('SOGo.AdministrationUI', ['ui.router', 'SOGo.Common', 'SOGo.Authentication', 'SOGo.PreferencesUI', 'SOGo.ContactsUI', 'SOGo.SchedulerUI', 'sgCkeditor'])
     .config(configure)
     .run(runBlock);
 
@@ -43,7 +43,28 @@
         },
         resolve: {
           stateUser: stateUser,
-          stateFolder: stateFolder
+          stateFolder: stateFolder,
+          stateAcls: stateAcls
+        }
+      })
+      .state('administration.theme', {
+        url: '/theme',
+        views: {
+          module: {
+            templateUrl: 'UIxThemePreview', // UI/Templates/Administration/UIxThemePreview.wox
+            controller: 'ThemePreviewController',
+            controllerAs: 'ctrl'
+          }
+        }
+      })
+      .state('administration.motd', {
+        url: '/motd',
+        views: {
+          module: {
+            templateUrl: 'UIxAdministrationMotd', // UI/Templates/Administration/UIxAdministrationMotd.wox
+            controller: 'AdministrationMotdController',
+            controllerAs: 'ctrl'
+          }
         }
       });
 
@@ -110,6 +131,11 @@
     return o;
   }
 
+  stateAcls.$inject = ['stateFolder'];
+  function stateAcls(stateFolder) {
+    return stateFolder.$acl.$users(stateFolder.owner);
+  }
+
   /**
    * @ngInject
    */
