@@ -7,8 +7,8 @@
   /**
    * @ngInject
    */
-  PreferencesController.$inject = ['$q', '$window', '$state', '$mdMedia', '$mdSidenav', '$mdDialog', '$mdToast', 'sgSettings', 'sgFocus', 'Dialog', 'User', 'Account', 'Preferences', 'Authentication'];
-  function PreferencesController($q, $window, $state, $mdMedia, $mdSidenav, $mdDialog, $mdToast, sgSettings, focus, Dialog, User, Account, Preferences, Authentication) {
+  PreferencesController.$inject = ['$q', '$window', '$state', '$mdMedia', '$mdSidenav', '$mdDialog', '$mdToast', 'sgSettings', 'sgFocus', 'Dialog', 'User', 'Account', 'Preferences', 'Authentication', 'AddressBook'];
+  function PreferencesController($q, $window, $state, $mdMedia, $mdSidenav, $mdDialog, $mdToast, sgSettings, focus, Dialog, User, Account, Preferences, Authentication, AddressBook) {
     var vm = this, mailboxes = [], today = new Date().beginOfDay();
 
     this.$onInit = function() {
@@ -17,8 +17,14 @@
       this.timeZonesList = $window.timeZonesList;
       this.timeZonesSearchText = '';
       this.addressesSearchText = '';
+      this.autocomplete = {forward: [], notification: []};
       this.mailLabelKeyRE = new RegExp(/^(?!^_\$)[^(){} %*\"\\\\]*?$/);
       this.emailSeparatorKeys = Preferences.defaults.emailSeparatorKeys;
+      if(this.preferences.defaults.Notification) {
+        if (!this.preferences.defaults.Notification.notificationMessage)
+          this.preferences.defaults.Notification.notificationMessage = l('Notification Message', $window.defaultEmailAddresses[0]);
+        this.preferences.defaults.Notification.notificationTranslated = l('Notification');
+      }
       if (Preferences.defaults.SOGoMailAutoMarkAsReadMode == 'delay')
         this.mailAutoMarkAsReadDelay = Math.max(1, this.preferences.defaults.SOGoMailAutoMarkAsReadDelay);
       else
@@ -55,6 +61,7 @@
           });
         });
     };
+    
 
     this.onDesktopNotificationsChange = function() {
       if (this.preferences.defaults.SOGoDesktopNotifications)
@@ -62,7 +69,7 @@
     };
 
     this.resetContactsCategories = function(form) {
-      this.preferences.defaults.SOGoContactsCategories = $window.defaultContactsCategories;
+      this.preferences.defaults.SOGoContactsCategories = $window.defaultContactsCategories.slice();
       form.$setDirty();
     };
 
@@ -97,10 +104,10 @@
       var i = _.indexOf(this.preferences.defaults.SOGoContactsCategories, "");
       if (i < 0) {
         this.preferences.defaults.SOGoContactsCategories.push("");
+        form.$setDirty();
         i = this.preferences.defaults.SOGoContactsCategories.length - 1;
       }
       focus('contactCategory_' + i);
-      form.$setDirty();
     };
 
     this.removeContactCategory = function(index, form) {
@@ -143,7 +150,8 @@
           defaults: this.preferences.defaults,
           account: account,
           accountId: index,
-          mailCustomFromEnabled: $window.mailCustomFromEnabled
+          mailCustomFromEnabled: $window.mailCustomFromEnabled,
+          maxSize: this.preferences.defaults.CDefaultsSize
         }
       }).then(function() {
         // Automatically expand the new mail account
@@ -171,7 +179,8 @@
           defaults: this.preferences.defaults,
           account: account,
           accountId: index,
-          mailCustomFromEnabled: $window.mailCustomFromEnabled
+          mailCustomFromEnabled: $window.mailCustomFromEnabled,
+          maxSize: this.preferences.defaults.CDefaultsSize
         }
       }).then(function() {
         vm.preferences.defaults.AuxiliaryMailAccounts[index] = account.$omit();
@@ -385,6 +394,13 @@
                  $window.forwardConstraintsDomains.indexOf(domain) < 0) {
           throw new Error(l("You are not allowed to forward your messages to this domain:") + " " + domain);
         }
+        else if ($window.forwardConstraints == 3 &&
+                  domains.indexOf(domain) < 0 &&
+                    ($window.forwardConstraintsDomains.length > 0 &&
+                    $window.forwardConstraintsDomains.indexOf(domain) < 0)) {
+          // If constraints mode is 3 and the domain is not an internal nor in forwardConstraintsDomains list, throw an error
+          throw new Error(l("You are not allowed to forward your messages to this domain:")+ " " + domain);
+        }
       }
 
       return true;
@@ -455,8 +471,10 @@
         });
       }
 
-      if (sendForm)
+      if (sendForm) {
+        var self = this;
         return this.preferences.$save().then(function(data) {
+          self.preferences.defaults.totpVerificationCode = ''
           if (!options || !options.quick) {
             $mdToast.show(
               $mdToast.simple()
@@ -465,11 +483,20 @@
                 .hideDelay(2000));
             form.$setPristine();
           }
+        }).catch(function(e) {
+          if (485 == e.status) {
+            form.totpVerificationCode.$setValidity('invalidTotpCode', false);
+          }
         });
+      }
 
       return $q.reject('Invalid form');
     };
 
+    this.resetTotpVerificationCode = function(form) {
+      form.totpVerificationCode.$setValidity('invalidTotpCode', true);
+    }
+
     this.canChangePassword = function(form) {
       if (this.passwords.newPasswordConfirmation && this.passwords.newPasswordConfirmation.length &&
           this.passwords.newPassword != this.passwords.newPasswordConfirmation) {
@@ -603,6 +630,107 @@
         }
       }
     };
+
+    this.contactFilter = function ($query) {
+      return AddressBook.$filterAll($query, [], {priority: 'gcs'}).then(function(cards) {
+        // Divide the matching cards by email addresses so the user can select
+        // the recipient address of her choice
+        var explodedCards = [];
+        _.forEach(_.invokeMap(cards, 'explode'), function(manyCards) {
+          _.forEach(manyCards, function(card) {
+            explodedCards.push(card);
+          });
+        });
+        // Remove duplicates
+        return _.uniqBy(explodedCards, function(card) {
+          return card.$$fullname + ' ' + card.$$email + ' ' + card.containername;
+        });
+      });
+    };
+
+    this.ignoreReturn = function ($event) {
+      if ($event.keyCode == 13) {
+        $event.stopPropagation();
+        $event.preventDefault();
+        return false;
+      }
+      if ($event.keyCode == 186 && $event.key == 'ü') { //Key code for separator ';' but is keycode for ü in german keyboard
+        $event.stopPropagation();
+        $event.preventDefault();
+        let element = $window.document.getElementById($event.target.id);
+        element.value = element.value + 'ü'
+      }
+    };
+
+    this.addRecipient = function (contact, element) {
+      var recipients, recipient, list, i, address;
+
+      recipients = this.autocomplete[element];
+
+      if (angular.isString(contact)) {
+        // Examples that are handled:
+        //   Smith, John <john@smith.com>
+        //   <john@appleseed.com>;<foo@bar.com>
+        //   foo@bar.com abc@xyz.com
+        address = '';
+        for (i = 0; i < contact.length; i++) {
+          if ((contact.charCodeAt(i) ==  9 ||   // tab
+               contact.charCodeAt(i) == 32 ||   // space
+               contact.charCodeAt(i) == 44 ||   // ,
+               contact.charCodeAt(i) == 59) &&  // ;
+              address.isValidEmail() &&
+              recipients.indexOf(address) < 0) {
+            recipients.push(address);
+            address = '';
+          }
+          else {
+            address += contact.charAt(i);
+          }
+        }
+        if (address && recipients.indexOf(address) < 0)
+          recipients.push(address);
+
+        return address;
+      }
+
+      if (contact.$isList({expandable: true})) {
+        // If the list's members were already fetch, use them
+        if (angular.isDefined(contact.refs) && contact.refs.length) {
+          _.forEach(contact.refs, function(ref) {
+            if (ref.email.length && recipients.indexOf(ref.$shortFormat()) < 0)
+              recipients.push(ref.$shortFormat());
+          });
+        }
+        else {
+          list = Card.$find(contact.container, contact.c_name);
+          list.$id().then(function(listId) {
+            _.forEach(list.refs, function(ref) {
+              if (ref.email.length && recipients.indexOf(ref.$shortFormat()) < 0)
+                recipients.push(ref.$shortFormat());
+            });
+          });
+        }
+      }
+      else if (contact.$isGroup({expandable: true})) {
+        recipient = {
+          toString: function () { return contact.$shortFormat(); },
+          isExpandable: true,
+          members: []
+        };
+        contact.$members().then(function (members) {
+          recipient.members = members;
+        });
+      }
+      else {
+        recipient = contact.$$email;
+      }
+      
+      if (recipient)
+        return recipient;
+      else
+        return null;
+    };
+
   }
 
   angular
