@@ -162,8 +162,8 @@
       Calendar.$subscribe(calendarData.owner, calendarData.name).then(function(data) {
          $mdToast.show(
            $mdToast.simple()
-             .content(l('Successfully subscribed to calendar'))
-             .position('top right')
+             .textContent(l('Successfully subscribed to calendar'))
+             .position(sgConstant.toastPosition)
              .hideDelay(3000));
       });
     };
